/**
 * @用途 环境配置类
 * @author 黄敏
 * @创建时间 2022-08-18 09:42
 **/

interface EnvConfig {
  baseApi: string
  mqttTopic: string
  eyeApi: string
  ticketUrl: string
  bbsUrl: string,
  extensionUrl:string,
}

//测试环境
let dev: Readonly<EnvConfig> = Object.freeze({
  baseApi: 'https://192.168.2.231/v1/api/',
  mqttTopic: 'test',
  eyeApi: 'https://fms3.hydrophis.cn:8000/api/v1/',
  ticketUrl: 'http://192.168.2.231:8001/',
  bbsUrl: 'http://testbbs.hydrophis.cn/',
  extensionUrl: 'https://192.168.2.231/ff-plugin-crawler/'
})

//生产环境
let pro: Readonly<EnvConfig> = Object.freeze({
  baseApi: 'https://fms3.hydrophis.cn/v1/api/',
  mqttTopic: 'fms',
  eyeApi: 'https://fms3.hydrophis.cn:8000/api/v1/',
  ticketUrl: 'http://ticket.hydrophis.cn/',
  bbsUrl: 'http://bbs.hydrophis.cn/',
  extensionUrl:'https://fms3.hydrophis.cn/ff-plugin-crawler/'
})

let config = TEST_SERVER ? dev : pro

class Env {
  static config = config

  static get localDomains(){
    let domains:string[] = []
    for (let i in dev){
      let url = dev[i as keyof typeof dev];
      if(!/^http/.test(url)) continue
      let o = new URL(url).origin
      if(!domains.includes(o)){
        domains.push(o)
      }
    }
    for (let i in pro){
      let url = pro[i as keyof typeof pro];
      if(!/^http/.test(url)) continue
      let o = new URL(url).origin
      if(!domains.includes(o)){
        domains.push(o)
      }
    }

    return domains;
  }

  static getBaseUrl(path: string): string {
    //@ts-ignore
    let dirname = (globalThis.window ? _pre_.__dirname : __dirname).replace(/\\/g, '/')

    return process.env.NODE_ENV === 'development' ? `http://localhost:${PORT}/${path}` : `file:///${dirname}/${path}`
  }

  //是否是本地的地址
  static isLocalUrl(url:string){
    return  Env.localDomains.some(d=>url.indexOf(d)===0)
  }

  /**
   * 获取注入基础地址
   * */
  static getPreloadUrl(path: string): string {
    //@ts-ignore
    return `${process.env.NODE_ENV === 'development' ? DEV_ROOT : globalThis.window ? _pre_.__dirname : __dirname}/${path}`
  }
}

export default Env
