/*
 * 分析文本类
 *
 * */

import {exclude_1688, exclude_tmall} from './analyze-text/config'
import util from '../../common/util'

interface ItemReturn {
  text: string //匹配完后剩余的文本
  data: string[] //匹配的结果
}

interface ContactInfoAndWebsite {
  info: f2.info.Info[]
  text: string
  website: string[]
}

export default class AnalyzeText {
  isCompany: boolean //是否是公司数据

  constructor(isCompany: boolean = false) {
    this.isCompany = isCompany
  }

  static getCommon(text: string, reg: RegExp, isUrl = false): ItemReturn {
    let res: any
    let strs: string[] = []
    let num = 0
    do {
      num++
      res = reg.exec(text)
      if (res && res[0]) {
        text = text.replace(res[0], '')

        if (isUrl && res[0].indexOf('http') === -1) {
          res[0] = 'https://' + res[0]
        }
        strs.push(res[0])
      }
    } while (res && num < 50)

    return {
      text: text, //匹配完后剩余的text
      data: strs
    }
  }

  static getCommonExclude1(text: string, reg: RegExp, excludes: string[], isUrl = false): ItemReturn {
    let res: any
    let strs: string[] = []
    let num = 0
    do {
      res = reg.exec(text)
      num++
      if (res && res[0]) {
        if (!excludes.includes(res[1])) {
          if (isUrl && res[0].indexOf('http') === -1) {
            res[0] += 'https://' + res[0]
          }

          strs.push(res[0])
        }
        text = text.replace(res[0], '')
      }
    } while (res && num < 50)

    return {
      text: text, //匹配完后剩余的text
      data: strs
    }
  }

  /*
   * 把 ItemReturn.data转成contact Info
   * */
  getDataInfo(arr: string[], type: f2.info.Type) {
    arr = util.arrayUnique(arr)
    return arr.map(f => {
      try {
        f = decodeURI(f)
      } catch (e) {
        console.log('decodeURI失败')
      }
      return {type: type, info: f}
    })
  }

  //获取联系方式
  //@param {boolean} hasGetWebSite 是否获取域名信息
  getContactInfo(text: string, hasGetWebSite = false): ContactInfoAndWebsite {
    text = text.replace(/​/g, '')
    let info: f2.info.Info[] = []

    let infoAndWebsite: ContactInfoAndWebsite = {
      info: info,
      text: text,
      website: []
    }

    //text不是字符串或字符串不超过5位，直接返回
    if (!text || typeof text !== 'string' || text.length < 3) {
      return infoAndWebsite
    }

    let data = this.getMediaContactInfo(text)

    if (this.isCompany) {
      info = data.companyInfos
    } else {
      info = data.contactInfos
    }

    //以下的不是域名
    let d: ItemReturn = {
      text: data.text,
      data: []
    }

    if (this.isCompany) {
      d = this.getAs(d.text)
      info.push(...this.getDataInfo(d.data, 'asnumber'))
    }

    d = this.getEmail(d.text)
    info.push(...this.getDataInfo(d.data, 'email'))

    d = this.getWechat(d.text)
    info.push(...this.getDataInfo(d.data, 'wechat'))

    d = this.getQq(d.text)
    info.push(...this.getDataInfo(d.data, 'qq'))

    d = this.getSkype(d.text)
    info.push(...this.getDataInfo(d.data, 'skype'))

    d = this.getPhone(d.text)
    info.push(...this.getDataInfo(d.data, 'phone'))

    d = this.getWebSite(d.text)

    if (hasGetWebSite) {
      infoAndWebsite.website = d.data
    }

    infoAndWebsite.info = info
    infoAndWebsite.text = d.text

    return infoAndWebsite
  }

  /*
   * 获取媒体类型的联系方式（带有URL）；如：linkedin,facebook等
   * @getAll 获取所有数据
   * */
  getMediaContactInfo(text: string, getAll = false): {contactInfos: f2.info.Info[]; companyInfos: f2.info.Info[]; text: string} {
    text = text.replace(/​/g, '')

    let contactInfos: f2.info.Info[] = [],
      companyInfos: f2.info.Info[] = []

    let info: f2.info.Info[] = []

    /*公共部分，可以是联系人的，也可以是公司的*/
    let d = this.getWiki(text)
    info.push(...this.getDataInfo(d.data, 'wiki'))

    d = this.getGithub(text)
    info.push(...this.getDataInfo(d.data, 'github'))

    d = this.getTwitter(d.text)
    info.push(...this.getDataInfo(d.data, 'twitter'))

    d = this.getInstagram(d.text)
    info.push(...this.getDataInfo(d.data, 'instagram'))

    d = this.getCrunchbase(d.text)
    info.push(...this.getDataInfo(d.data, 'crunchbase'))

    d = this.getYoutube(d.text)
    info.push(...this.getDataInfo(d.data, 'youtube'))

    d = this.getLinkedin(d.text)

    info.push(...this.getDataInfo(d.data, 'linkedin'))
    d = this.getWeibo(d.text)
    info.push(...this.getDataInfo(d.data, 'weibo'))

    d = this.getWsj(d.text)
    info.push(...this.getDataInfo(d.data, 'wsj'))

    d = this.getMedium(d.text)
    info.push(...this.getDataInfo(d.data, 'medium'))

    /*只有公司的数据*/
    if (this.isCompany || getAll) {
      d = this.getDnb(d.text)
      companyInfos.push(...this.getDataInfo(d.data, 'dnb'))

      d = this.getJd(d.text)
      companyInfos.push(...this.getDataInfo(d.data, 'jd'))

      d = this.getOpencorporates(d.text)
      companyInfos.push(...this.getDataInfo(d.data, 'opencorporates'))

      d = this.get1688(d.text)
      companyInfos.push(...this.getDataInfo(d.data, 'alibaba'))

      d = this.getAlibaba(d.text)
      companyInfos.push(...this.getDataInfo(d.data, 'alibaba'))

      d = this.getCraft(d.text)
      companyInfos.push(...this.getDataInfo(d.data, 'craft'))

      d = this.getTmall(d.text)
      companyInfos.push(...this.getDataInfo(d.data, 'tmall'))

      d = this.getEbay(d.text)
      companyInfos.push(...this.getDataInfo(d.data, 'ebay'))

      d = this.getAmazon(d.text)
      companyInfos.push(...this.getDataInfo(d.data, 'amazon'))

      /*有联系人的，也有公司的*/
      d = this.getFacebook(d.text, true)
      companyInfos.push(...this.getDataInfo(d.data, 'facebook'))

      d = this.getTianyancha(d.text, true)
      companyInfos.push(...this.getDataInfo(d.data, 'tianyancha'))

      d = this.getQcc(d.text, true)
      companyInfos.push(...this.getDataInfo(d.data, 'qcc'))
      d = this.getZhihu(d.text, true)
      companyInfos.push(...this.getDataInfo(d.data, 'zhihu'))

      d = this.getItjuzi(d.text, true)

      companyInfos.push(...this.getDataInfo(d.data, 'itjuzi'))

      d = this.getPedaily(d.text, true)
      companyInfos.push(...this.getDataInfo(d.data, 'pedaily'))

      d = this.getCyzone(d.text, true)
      companyInfos.push(...this.getDataInfo(d.data, 'cyzone'))

      d = this.getQixin(d.text, true)
      companyInfos.push(...this.getDataInfo(d.data, 'qixin'))

      d = this.getMedium(d.text, true)
      companyInfos.push(...this.getDataInfo(d.data, 'medium'))

      d = this.getPaganresearch(d.text)
      companyInfos.push(...this.getDataInfo(d.data, 'paganresearch'))
    }

    if (!this.isCompany || getAll) {
      /*有联系人的，也有公司的*/
      d = this.getFacebook(d.text, false)
      contactInfos.push(...this.getDataInfo(d.data, 'facebook'))

      d = this.getTianyancha(d.text, false)
      contactInfos.push(...this.getDataInfo(d.data, 'tianyancha'))
      d = this.getQcc(d.text, false)
      contactInfos.push(...this.getDataInfo(d.data, 'qcc'))
      d = this.getZhihu(d.text, false)
      contactInfos.push(...this.getDataInfo(d.data, 'zhihu'))

      d = this.getItjuzi(d.text, false)

      contactInfos.push(...this.getDataInfo(d.data, 'itjuzi'))

      d = this.getPedaily(d.text, false)
      contactInfos.push(...this.getDataInfo(d.data, 'pedaily'))

      d = this.getCyzone(d.text, false)
      contactInfos.push(...this.getDataInfo(d.data, 'cyzone'))

      d = this.getQixin(d.text, false)
      contactInfos.push(...this.getDataInfo(d.data, 'qixin'))

      d = this.getMedium(d.text, false)
      contactInfos.push(...this.getDataInfo(d.data, 'medium'))

      d = this.getWordpress(d.text, false)
      contactInfos.push(...this.getDataInfo(d.data, 'wordpress'))
    }

    if (this.isCompany) {
      companyInfos.push(...info)
    } else {
      contactInfos.push(...info)
    }

    return {
      text: d.text,
      contactInfos: util.arrayUnique(contactInfos),
      companyInfos: util.arrayUnique(companyInfos)
    }
  }

  //获取网址
  getWebSite(text: string) {
    let website = /http(s)?:\/\/[^.]+\.[^\n\f\r\t\v 　]+/i

    let items: ItemReturn = {
      data: [],
      text: ''
    }

    let d = AnalyzeText.getCommon(text, website, true)
    items.text = d.text
    if (d.data.length) {
      items.data.push(...d.data)
    }
    let reg: RegExp =
      /\w+(?:\.\w+){0,2}\.(?:partners|tech|com|arpa|edu|gov|int|mil|net|org|biz|info|pro|name|museum|coop|aero|xxx|idv|mobi|asia|jobs|tel|travel|cloud|network|digital|me|ax|bl|bq|cat|cw|gb|al|mf|rs|su|sx|dz|af|ar|ae|aw|om|az|eg|et|ie|ee|ad|ao|ai|ag|at|au|mo|bb|pg|bs|pk|py|ps|bh|pa|br|by|bm|bg|mp|bj|be|is|pr|ba|pl|bo|bz|bw|bt|bf|bi|bv|kp|gq|dk|de|tl|tp|tg|dm|do|ru|ec|er|fr|fo|pf|gf|tf|va|ph|fj|fi|cv|fk|gm|cg|cd|co|cr|gg|gd|gl|ge|cu|gp|gu|gy|kz|ht|kr|nl|an|hm|hn|ki|dj|kg|gn|gw|ca|gh|ga|kh|cz|zw|cm|qa|ky|km|ci|kw|cc|hr|ke|ck|lv|ls|la|lb|lt|lr|ly|li|re|lu|rw|ro|mg|im|mv|mt|mw|my|ml|mk|mh|mq|yt|mu|mr|us|um|as|vi|mn|ms|bd|pe|fm|mm|md|ma|mc|mz|mx|nr|np|ni|ne|ng|nu|no|nf|na|za|aq|gs|eu|pw|pn|pt|jp|se|ch|sv|ws|yu|sl|sn|cy|sc|sa|cx|st|sh|kn|lc|sm|pm|vc|lk|sk|si|sj|sz|sd|sr|sb|so|tj|tw|th|tz|to|tc|tt|tn|tv|tr|tm|tk|wf|vu|gt|ve|bn|ug|ua|uy|uz|es|eh|gr|hk|sg|nc|nz|hu|sy|jm|am|ac|ye|iq|ir|il|it|in|id|uk|vg|io|jo|vn|zm|je|td|gi|cl|cf|cn|yr)(?:[/?&#][^\n\f\r\t\v]*|\b)/m
    let res: any
    let num = 0
    do {
      num++
      res = reg.exec(items.text)
      if (res && res[0]) {
        items.data.push('https://' + res[0])
        items.text = items.text.replace(res[0], '')
      }
    } while (res && num < 50)

    return items
  }

  //获取facebook
  getFacebook(text: string, isCompany = this.isCompany): ItemReturn {
    let facebook = /(?:https?:\/\/)?(?:[^.]*?\.)?facebook\.com\/(\S+).*$/i
    let facebook2 = /(?:https?:\/\/?)(?:[^.]*?\.)?facebook.com\/profile.php\?.*?id=(\d+).*$/

    let res: any
    let strs: string[] = []
    let num = 0
    do {
      let res = facebook.exec(text)
      num++
      if (!res && !isCompany) res = facebook2.exec(text)

      if (res) {
        let url = `https://www.facebook.com/${res[1]}`

        strs.push(url)
        text = text.replace(res[0], '')
      }
    } while (res && num < 50)

    return {
      text: text,
      data: strs
    }
  }

  //获取京东
  getJd(text: string) {
    let jd = /https?:\/\/mall.jd.com\/index-\d+\.html/i
    return AnalyzeText.getCommon(text, jd, true)
  }

  //获取wiki
  getWiki(text: string): ItemReturn {
    let wiki = /(https?:\/\/([^.]*?\.)?)?wikipedia\.org\/\S+/i
    return AnalyzeText.getCommon(text, wiki, true)
  }

  //获取Twitter
  getTwitter(text: string): ItemReturn {
    let twitter = /(https?:\/\/([^.]*?\.)?)?twitter\.com\/\S+/i
    return AnalyzeText.getCommon(text, twitter, true)
  }

  //获取 instagram
  getInstagram(text: string): ItemReturn {
    let instagram = /(https?:\/\/)?([^.]*?\.)?instagram\.com\/\S+/i
    return AnalyzeText.getCommon(text, instagram, true)
  }

  //获取 zhihu
  getZhihu(text: string, isCompany = this.isCompany): ItemReturn {
    let reg = isCompany ? /(?:https?:\/\/)?www\.zhihu\.com\/(people|org)\/[\w-]+/i : /(?:https?:\/\/)?www\.zhihu\.com\/people\/[\w-]+/i
    return AnalyzeText.getCommon(text, reg, true)
  }

  //获取 it桔子
  getItjuzi(text: string, isCompany = this.isCompany): ItemReturn {
    let reg = isCompany ? /(https?:\/\/)?www\.itjuzi\.com\/(company|investfirm)\/\d+/i : /(https?:\/\/)?www\.itjuzi\.com\/person\/\d+/i
    return AnalyzeText.getCommon(text, reg, true)
  }

  //获取 craft
  getCraft(text: string): ItemReturn {
    let reg = /(https?:\/\/)?craft\.co\/[\w-]+/i
    return AnalyzeText.getCommon(text, reg, true)
  }

  //获取 it桔子
  getPedaily(text: string, isCompany = this.isCompany): ItemReturn {
    let reg = isCompany ? /(https?:\/\/)?zdb\.pedaily\.cn\/(enterprise|company)\/show\d+/ : /(https?:\/\/)?zdb\.pedaily\.cn\/people\/show\d+/i
    return AnalyzeText.getCommon(text, reg, true)
  }

  //获取 创业帮
  getCyzone(text: string, isCompany = this.isCompany): ItemReturn {
    let res: any
    let strs: string[] = []

    if (isCompany) {
      let reg1 = /(?:https?:\/\/)?(?:data|www)\.cyzone\.cn\/(company|capital)\/(\d+)\.html/

      let reg2 = /(?:https?:\/\/)?data\.cyzone\.cn\/content\/dbase\/(company|capital).*?&content_id=(\d+)/
      let num = 0
      do {
        res = reg1.exec(text) || reg2.exec(text)

        num++
        if (res) {
          let url = `https://data.cyzone.cn/${res[1]}/${res[2]}.html`

          strs.push(url)
          text = text.replace(res[0], '')
        }
      } while (res && num < 50)
    } else {
      let reg = /(?:https?:\/\/)?data\.cyzone\.cn\/(investor\/\d+\.html|author\/\d+)/i
      let num = 0
      do {
        num++
        res = reg.exec(text)

        if (res) {
          let url = `https://data.cyzone.cn/${res[1]}`
          strs.push(url)
          text = text.replace(res[0], '')
        }
      } while (res && num < 50)
    }

    return {
      text: text,
      data: strs
    }
  }

  //获取 crunchbase
  getCrunchbase(text: string, isCompany = this.isCompany): ItemReturn {
    let crunchbase = isCompany ? /(?:https?:\/\/)?(?:[^.]*?\.)?crunchbase\.com\/(organization)\/(\S+)/i : /(?:https?:\/\/)?(?:[^.]*?\.)?crunchbase\.com\/(person)\/(\S+)/i
    let res: any
    let strs: string[] = []
    let num = 0
    do {
      num++
      res = crunchbase.exec(text)
      if (res) {
        let url = `https://www.crunchbase.com/${res[1]}/${res[2]}`
        strs.push(url)
        text = text.replace(res[0], '')
      }
    } while (res && num < 50)
    return {
      text: text,
      data: strs
    }
  }

  ///^https?:\/\/paganresearch\.io\/(details)\/[\w-]{2,}/,  获取paganresearch
  getPaganresearch(text: string): ItemReturn {
    let reg = /(https?:\/\/)?paganresearch\.io\/details\/([\w-]+)/i
    let res: any
    let strs: string[] = []
    let num = 0
    do {
      num++
      res = reg.exec(text)
      if (res) {
        let url = `https://paganresearch.io/details/${res[2]}`
        strs.push(url)
        text = text.replace(res[0], '')
      }
    } while (res && num < 50)
    return {
      text: text,
      data: strs
    }
  }

  //获取 youtube
  getYoutube(text: string): ItemReturn {
    let youtube = /https?:\/\/([^.]*?\.)?youtube\.com\/\S+/i
    return AnalyzeText.getCommon(text, youtube, true)
  }

  //获取 Pinterest
  getPinterest(text: string): ItemReturn {
    let pinterest = /(?:https?:\/\/)?([^.]*?\.)?pinterest\.com\/\S+/i
    return AnalyzeText.getCommon(text, pinterest, true)
  }

  //获取 阿里巴巴
  get1688(text: string): ItemReturn {
    let reg = /(?:https?:\/\/)?([^.]+)\.1688\.com/i
    return AnalyzeText.getCommonExclude1(text, reg, exclude_1688, true)
  }

  //获取 阿里巴巴国际站
  getAlibaba(text: string): ItemReturn {
    let alibaba = /(?:https?:\/\/)?([^.]*?)\.en\.alibaba\.com/i
    return AnalyzeText.getCommon(text, alibaba, true)
  }

  //获取 天猫
  getTmall(text: string): ItemReturn {
    let reg = /(?:https?:\/\/)?([^.]+?)\.tmall\.com[^ ]+/i
    return AnalyzeText.getCommonExclude1(text, reg, exclude_tmall, true)
  }

  //获取 ebay
  getEbay(text: string): ItemReturn {
    let reg = /(?:https?:\/\/)?([^.]+?)\.ebay\.com\/usr\/[^?\s;,]+/i
    return AnalyzeText.getCommon(text, reg, true)
  }

  //获取 亚马逊
  getAmazon(text: string): ItemReturn {
    let reg = /(?:https?:\/\/)?www.amazon.com\/(?:sp?\?.*?(?:seller|me)=([^&?\s]+))/

    let res: any
    let strs: string[] = []
    let num = 0
    do {
      num++
      res = reg.exec(text)
      if (res) {
        let url = `https://www.amazon.com/sp?seller=${res[1]}`
        strs.push(url)
        text = text.replace(res[0], '')
      }
    } while (res && num < 50)

    return {
      text: text,
      data: strs
    }
  }

  //获取Wordpress
  getWordpress(text: string, isCompany: boolean = this.isCompany): ItemReturn {
    let reg = /(https?:\/\/)?profiles\.wordpress\.org\/(.*?\/)/i

    let res: any
    let strs: string[] = []
    let num = 0
    do {
      num++
      res = reg.exec(text)
      if (res) {
        let url = `https://profiles.wordpress.org/${res[2]}`
        strs.push(url)
        text = text.replace(res[0], '')
      }
    } while (res && num < 50)

    return {
      text: text,
      data: strs
    }
  }

  //微博
  getWeibo(text: string) {
    let reg = /(?:https?:\/\/)?(\w+?\.)?weibo\.com\/(u\/)?[^?&\s]{2,}/i
    return AnalyzeText.getCommon(text, reg, true)
  }

  //获取 Linkedin
  getLinkedin(text: string, isCompany = this.isCompany): ItemReturn {
    let com = /(?:https?:\/\/www\.)?linkedin.com\/(company)\/([^ /?]+)\/?/i
    let cont = /(?:https?:\/\/www\.)?linkedin.com\/(in)\/([^ /?]+)\/?/i

    let linkedin = isCompany ? com : cont
    let res: any
    let strs: string[] = []

    if (isCompany) {
      text = text.replace(/(?:https?:\/\/www\.)?linkedin.com\/(in)\/([^/?]+)\/?/gi, '')
    } else {
      text = text.replace(/(?:https?:\/\/www\.)?linkedin.com\/(company)\/([^/?]+)\/?/gi, '')
    }
    let num = 0
    do {
      num++
      res = linkedin.exec(text)
      if (res) {
        let url = `https://www.linkedin.com/${res[1]}/${res[2]}`
        strs.push(url)
        text = text.replace(res[0], '')
      }
    } while (res && num < 50)

    return {
      text: text,
      data: strs
    }
  }

  //获取 github
  getGithub(text: string): ItemReturn {
    let github = /(https?:\/\/)?github.com\/\S+/i
    return AnalyzeText.getCommon(text, github, true)
  }

  //获取 wsj
  getWsj(text: string, isCompany = this.isCompany): ItemReturn {
    let wsj = isCompany
      ? /(?:https?:\/\/www\.)?wsj.com\/market-data\/quotes\/([a-zA-Z]{2,}(?:(?:\/\w+){2})?)(?:\/company-people)?/i
      : /(?:https?:\/\/www\.)?wsj.com\/market-data\/quotes\/([a-zA-Z]{2,}(?:\/\w+){0,2}\/company-people\/executive-profile\/\d+)/i
    let res: any
    let strs: string[] = []
    let num = 0
    do {
      num++
      res = wsj.exec(text)
      if (res) {
        let url = `https://www.wsj.com/market-data/quotes/${res[1]}`
        strs.push(url)
        text = text.replace(res[0], '')
      }
    } while (res && num < 50)

    return {
      text: text,
      data: strs
    }
  }

  //获取medium
  //https://medium.com/@mbitty
  // https://seandexter1.medium.com/
  getMedium(text: string, isCompany: boolean = this.isCompany): ItemReturn {
    let medium = isCompany ? /(?:https?:\/\/)(\w+\.)medium\.com(\/\w+)?(\/about)?/ : /(?:https?:\/\/)(\w+\.)?medium\.com(\/@\w+)(\/about)?/

    let res: any
    let strs: string[] = []
    let num = 0
    do {
      num++
      res = medium.exec(text)
      if (res) {
        if (!res[1]) res[1] = ''
        if (!res[2]) res[2] = ''
        let url = `https://${res[1]}medium.com${res[2]}`
        strs.push(url)
        text = text.replace(res[0], '')
      }
    } while (res && num < 50)

    return {
      text: text,
      data: strs
    }
  }

  //获取 Dnb
  getDnb(text: string): ItemReturn {
    let dnb = /dnb.com\/business-directory\/company-profiles.(\S+)\.(\S+)(.html)?/i
    let res: any
    let strs: string[] = []
    let num = 0
    do {
      num++
      res = dnb.exec(text)
      if (res) {
        let url = `https://www.dnb.com/business-directory/company-profiles.${res[1]}.${res[2]}.html`
        strs.push(url)
        text = text.replace(res[0], '')
      }
    } while (res && num < 50)

    return {
      text: text,
      data: strs
    }
  }

  //获取 opencorporates
  getOpencorporates(text: string): ItemReturn {
    let strs: string[] = []

    let opencorporates = /(?:https?:\/\/)?opencorporates.com\/companies\/(\S+)/i
    let res: any
    let num = 0
    do {
      res = opencorporates.exec(text)
      num++
      if (res) {
        let url = `https://opencorporates.com/companies/${res[1]}`
        strs.push(url)
        text = text.replace(res[0], '')
      }
    } while (res && num < 50)

    return {
      text: text,
      data: strs
    }
  }

  //获取 Tianyancha
  getTianyancha(text: string, isCompany = this.isCompany): ItemReturn {
    let strs: string[] = []

    let tianyancha = isCompany ? /tianyancha.com\/(company|brand|organize)\/(\S+)/i : /tianyancha.com\/(human)\/(\S+)/i
    let res: any
    let num = 0
    do {
      res = tianyancha.exec(text)
      num++
      if (res) {
        let url = `https://www.tianyancha.com/${res[1]}/${res[2]}`
        strs.push(url)
        text = text.replace(res[0], '')
      }
    } while (res && num < 50)

    return {
      text: text,
      data: strs
    }
  }

  //获取 企查查
  getQcc(text: string, isCompany = this.isCompany): ItemReturn {
    let strs: string[] = []

    let qichacha = isCompany ? /qcc.com\/((?:firm\/|groupdetail_|product\/)\S+\.html)/i : /qcc.com\/(pl\/\S+)/i
    let res: any
    let num = 0
    do {
      num++
      res = qichacha.exec(text)
      if (res) {
        let url = `https://www.qcc.com/${res[1]}`
        strs.push(url)
        text = text.replace(res[0], '')
      }
    } while (res && num < 50)

    return {
      text: text,
      data: strs
    }
  }

  //获取 企信宝数据
  getQixin(text: string, isCompany = this.isCompany): ItemReturn {
    let reg = isCompany ? /(https?:\/\/)?www.qixin.com\/(company|investor|brand)\/[^?\s]+/i : /(https?:\/\/)?www.qixin.com\/(name-detail|shareholder)\/[^?\s]+/i
    return AnalyzeText.getCommon(text, reg, true)
  }

  //获取 as
  getAs(text: string): ItemReturn {
    let as = /(as ?\d{1,7})($|\D)/i
    let res: any
    let strs: string[] = []
    let num = 0
    do {
      num++
      res = as.exec(text)

      if (res) {
        strs.push(res[1])
        text = text.replace(res[0], '')
      }
    } while (res && num < 50)

    return {
      text: text,
      data: strs
    }
  }

  //获取 Email
  getEmail(text: string): ItemReturn {
    let emailReg = /[\w-.]+?(@|\(at\))[\w-]+?\.[\w-]+(\.[\w-]+)?/gi
    let res: any
    let strs: string[] = []
    let num = 0
    do {
      num++
      res = emailReg.exec(text)

      if (res) {
        strs.push(res[0])
      }
    } while (res && num < 50)
    return {
      text: text,
      data: strs
    }
  }

  //获取 Wechat
  getWechat(text: string): ItemReturn {
    let wechat = /(wechat|微信号?是?)[: 　：.]?[: 　：.]?(\w{4,20})/i
    let reg1 = /https?:\/\/open\.weixin\.qq\.com\/qr\/code\?username=[\w-+]+/
    let reg2 = /https?:\/\/u\.wechat\.com\/[\w-+]+|https?:\/\/weixin\.qq\.com\/r\/[\w-+]+/

    let res: any
    let strs: string[] = []
    let num = 0
    do {
      res = reg1.exec(text)
      num++
      if (res) {
        strs.push(res[0])
        text = text.replace(res[0], '')
      }
    } while (res && num < 50)
    num = 0
    do {
      res = reg2.exec(text)
      num++
      if (res) {
        strs.push(res[0])
        text = text.replace(res[0], '')
      }
    } while (res && num < 50)
    num = 0
    do {
      num++
      res = wechat.exec(text)
      if (res) {
        strs.push(res[2])
        text = text.replace(res[2], '')
      }
    } while (res && num < 50)
    // if (strs.length > 2) {
    // 	strs.splice(2,strs.length)
    // }

    return {
      text: text,
      data: strs
    }
  }

  //获取 qq
  getQq(text: string): ItemReturn {
    //qq1
    let qq1 = /qq[: 　：.]?[: 　：.]??(\d{5,14})($|\D)/i
    //qq2 从qq邮箱拿到qq
    let qq2 = /(\d{6,14})@qq.com/g

    let res: any
    let strs: string[] = []
    let num = 0
    do {
      res = qq1.exec(text)
      num++
      if (res) {
        strs.push(res[1])
        text = text.replace(res[1], '')
      }
    } while (res && num < 50)
    num = 0
    do {
      num++
      res = qq2.exec(text)
      if (res) {
        strs.push(res[1])
        text = text.replace(res[1], '')
      }
    } while (res && num < 50)

    return {
      text: text,
      data: strs
    }
  }

  //获取 getSkype
  getSkype(text: string): ItemReturn {
    //qq1
    let skype = /skype[: 　：.]?[: 　：.]?(\w[\w.]{1,18}\w)/i

    let res: any
    let strs: string[] = []
    let num = 0 //循环不能超过50
    do {
      num++
      res = skype.exec(text)
      if (res) {
        strs.push(res[1])
        text = text.replace(res[1], '')
      }
    } while (res && num < 50)

    return {
      text: text,
      data: strs
    }
  }

  //获取 Phone
  getPhone(text: string): ItemReturn {
    let res: any
    let strs: string[] = []

    //是否是日期
    let isDate = /\D?((1[89]\d\d|2[01]\d\d)[- ._/]?(0[1-9]|1[012])[- ._/]?(0[1-9]|[12][0-9]|3[01])|((0[1-9]|[12][0-9]|3[01]))[- ._/]?(0[1-9]|[12][0-9]|3[01])[- ._/]?(1[89]\d\d|2[01]\d\d))/

    //场景1，单独匹配该格式 +213 (029) 27 22 80 / 27 22 06 或 (029) 27 22 80 / 27 22 06
    //把国家区号和城市区号拉过去    国家区号   区号     电话1        电话2
    //["(029) 27 22 80/27 22 06", undefined, "029", "27 22 80", "27 22 06", index: 0, input: "(029) 27 22 80/27 22 06awefwaefwaef", groups: undefined]
    let scenario1 = /(?:(\+\d+) {1,2})?\((\d+)\) ((?:\d+ ){1,3}\d+) {0,3}\/ {0,3}((?:\d+ ){1,3}\d+)/
    let scenario1Global = new RegExp(scenario1, 'g')
    let scenario1Phone = text.match(scenario1Global)
    if (scenario1Phone) {
      scenario1Phone.forEach(v => {
        text = text.replace(v, '')
        let data = v.match(scenario1)
        if (data) {
          let phone1 = `${data[1] ? data[1] + ' ' : ''}${data[2]}${data[3]}`
          let phone2 = `${data[1] ? data[1] + ' ' : ''}${data[2]}${data[4]}`
          strs.push(phone1, phone2)
        }
      })
    }
    // 匹配没有空格的电话号码
    //+94703030666 0702020666
    let scenario2 = /(\+\d{1,4} {0,3}\d{6,13}) +(\d{6,13})/
    let scenario2Global = new RegExp(scenario2, 'g')
    let scenario2Phone = text.match(scenario2Global)
    if (scenario2Phone) {
      scenario2Phone.forEach(v => {
        text = text.replace(v, '')

        let data = v.match(scenario2)
        if (data) {
          let phone1 = data[1]
          let areacode = ff.country.getPhoneAreaCode(data[1])
          let phone2 = (areacode ? `+${areacode}` : '') + data[2]

          strs.push(phone1, phone2)
        }
      })
    }

    //匹配 +7(495)5329101 / 7(495)5329101
    let scenario3 = /(\+?\d{1,4} {0,3}\(\d{2,5}\)\d{6,13})/
    let scenario3Global = new RegExp(scenario3, 'g')
    let scenario3Phone = text.match(scenario3Global)
    if (scenario3Phone) {
      scenario3Phone.forEach(v => {
        text = text.replace(v, '')

        let data = v.match(scenario3)
        if (data) {
          strs.push(data[1])
        }
      })
    }

    //匹配带横杠的格式
    //970-562-1824 86-970-562-1824 +86-970-5162-1824 +86 970-5262-1824 (86) 970-5362-1824 (86)-970-5462-1824
    //(+86) 970-5562-1824 +(86) 970-5662-1824 +(86).970-5762-1824 86.970-5862-1824 +86.970-5962-1824 (86).970-6062-1824
    let hengGang = /(\+?\d+[ \-.]{0,2}|\(\+?\d+\)[- .]{0,2}|\+\(\d+\)[- .]{0,2})?(\d+-){2,3}\d+/g
    let hengGangPhone = text.match(hengGang)
    if (hengGangPhone) {
      hengGangPhone.forEach(v => {
        text = text.replace(v, '')
        strs.push(v)
      })
    }

    //通用匹配
    let common = /\+?(?:\d+[. -])?(?:\(\d{1,5}\) *)?\d[\d\- .]{4,16}\d+/g
    let commonPhone = text.match(common)
    if (commonPhone) {
      commonPhone.forEach(v => {
        text = text.replace(v, '')
        strs.push(v)
      })
    }

    if (strs.length) {
      //过滤日期的格式
      strs = strs.filter(v => {
        let arr = v.split(/ +/)
        let noSp = v.replace(/[. ,+]/, '')
        //不能少于7位
        if (noSp.length < 7) {
          return false
        }

        //美国的电话不能小于10位
        if (arr[0] === '1' && arr[1] && noSp.length < 10) {
          return false
        }

        if (isDate.test(v)) {
          return false
        } else if (v.replace(/\D/g, '').length > 14) {
          return false
        } else {
          return true
        }
      })
    }

    //如果国家区有括号号（86）转成+86
    if (strs.length) {
      strs = strs.map(v => {
        return v.replace(/^\+?\(\+?(\d+)\)/, '+$1')
      })
    }

    //去重操作
    let newStrs: string[] = []
    strs.forEach(v => {
      let d = v.replace(/\D/g, '')

      let isReplace = false

      let index = newStrs.findIndex(v2 => {
        let d2 = v2.replace(/\D/g, '')
        if (d === d2) {
          if ((v.indexOf('+') === 0 && !v2.includes('+')) || v.length > v2.length) {
            isReplace = true
          }
          return true
        } else if (d2.includes(d)) {
          return true
        } else if (d.includes(d2)) {
          isReplace = true
          return true
        }

        return false
      })

      if (index === -1) {
        newStrs.push(v)
      } else if (isReplace) {
        newStrs.splice(index, 1, v)
      }
    })

    return {
      text: text,
      data: newStrs
    }
  }
}
