import accountConfig from './contactInfo/account-info'
import contactConfig from './contactInfo/contact-info'
/**
 * @用途
 * @author 黄敏
 * @创建时间 2022-08-10 15:39
 **/

interface ToInfoReturn {
  type: Crawler.DataType | 'indetermination'
  data: Crawler.ContactInfo
}

class ContactInfo {

  static contactConfig = contactConfig
  static accountConfig = accountConfig

  static getUrlType(d: string) {

    if(d.includes('wikipedia.org/wiki')){
      return 'wiki'
    }

    let type = ''
    if (d) {
      if(d.indexOf('http')===0){
        d = new URL(d).hostname

      }

     let  arr = d.split('.').reverse().map(v=>v.toLowerCase())

      if(contactConfig[<f2.info.Type>arr[1]]){
        type = arr[1]
      }else if(arr[2] && contactConfig[<f2.info.Type>arr[2]]){
        type = arr[2]
      }
    }

    return <f2.info.Type>type
  }

  static validate(type: f2.info.Type, info: string, isContact = false) {
    let conf = isContact ? ContactInfo.contactConfig[type] : ContactInfo.accountConfig[type]
    if (conf) {
      if (conf.regular) return conf.regular.test(info)
      else return true
    } else {
      return false
    }
  }

  /**
   * 新建一个新的联系方式
   * @param type 联系方式类型
   * @param info 联系试式内容
   * @param countryId 国家id
   * */
  static newInfo(type: f2.info.Type, info: string = '', countryId: number = 0): f2.info.Info {
    return {
      type: type,
      info: info,
      country_id: countryId,
      remark: '',
      ext: '',
      phone_type: 0
    }
  }

  //把一个url转换成info
  //@param url 地址
  //@return ToInfoReturn|null 联系试式内容
  static urlToInfo(url: string): ToInfoReturn | null {

    let type = this.getUrlType(url)

    let getData: (type: f2.info.Type) => ToInfoReturn | null = type => {
      let info: f2.info.Info = {
        type: type,
        info: url
      }
      let hasAccount = accountConfig[type] && ContactInfo.validate(type, url)
      let hasContact = contactConfig[type] && ContactInfo.validate(type, url, true)
      if (hasAccount && hasContact) {
        return {
          type: 'indetermination',
          data: info
        }
      } else if (hasAccount) {
        return {
          type: 'company',
          data: info
        }
      } else if (hasContact) {
        return {
          type: 'contact',
          data: info
        }
      } else {
        return null
      }
    }

    if (type) {
      return getData(type)
    }  else {
      return null
    }
  }

  /*
   * 获取facebook中的uid
   * */
  static getFacebookUID(url: string): string {
    let exd = [
      '.com/photo.php?',
      '.com/friends/',
      '.com/pages',
      '.com/business/',
      '.com/search',
      '.com/public/',
      '.com/policies',
      '.com/fundraisers/',
      '.com/messages/',
      '.com/watch/',
      '.com/groups/',
      '.com/help',
      '.com/find-friends',
      '.com/share.php',
      '.com/sharer.php',
      '.com/projects',
      '.com/login',
      '.com/?',
      '.com/&',
      'developers.facebook.com',
      '.com/recover',
      '.com/r.php',
      '.com/checkpoint',
      '.com/adsmanager/',
      '.com/ads/',
      '.com/ad_campaign',
      '.com/home.php'
    ]

    if (exd.some(v => url.indexOf(v) > -1)) {
      return ''
    }

    let reg = /^https?:\/\/(?:[\w\-]+\.)?facebook\.com\/([^\/&?]*?)(\/?|\/.*?|&.*?|\?.*?)$/
    let reg2 = /^https?:\/\/(?:[\w\-]+\.)?facebook\.com\/profile.php\?id=(.*?)(&.*?)?$/
    let reg3 = /^https?:\/\/(?:[\w\-]+\.)?facebook\.com\/people\/.*?\/(.*?)$/
    let reg4 = /^https?:\/\/(?:[\w\-]+\.)?facebook\.com\/pg\/(.*?)(\/\S*)?$/

    let datas

    //地址(url)必须是facebook个人页面
    if (reg4.test(url)) {
      datas = reg4.exec(url)
    } else if (reg3.test(url)) {
      datas = reg3.exec(url)
    } else if (reg2.test(url)) {
      datas = reg2.exec(url)
    } else if (reg.test(url)) {
      datas = reg.exec(url)
    } else {
      return ''
    }

    //获取正则子串 ([^\/]*?)的内容,正是urlId
    if (!datas) return ''
    return decodeURI(datas[1]).toLowerCase()
  }

  /**
   * 获取联系方式id
   * @param {string} type 通讯类型 有linkedin,facebook,twitter,email等
   * @param {string} info 联系方式内容
   * @param {boolean} hasHtml 是否支持html代码
   * @param {boolean} 是否是contact数据
   * @return {string} 通讯的图标类
   * */
  static getInfoId(type: f2.info.Type, info: string | number, hasHtml = false, isContact = false): string {
    info = String(info)

    if (type === 'facebook') {
      return ContactInfo.getFacebookUID(info)
    }

    let conf = isContact ? contactConfig[type] : accountConfig[type]
    if (conf) {
      if (!conf.id) return info

      let id: string
      let reg = conf.id.exec(info)

      if (reg) {
        id = reg[1]
      } else {
        id = info
      }

      if (hasHtml && type === 'tianyancha' && id) {
        if (id.indexOf('brand/') === 0) {
          id = id.replace('brand/', '<span class="f-label f-label-green">brand</span>')
        } else if (id.includes('company/')) {
          id = id.replace('company/', '<span class="f-label f-label-green">company</span>')
        }
      }

      return id ?? ''
    } else {
      console.warn('err', type, info)
      return ''
    }
  }
}

export default ContactInfo
