import contactConfig from './contact-info'

const config = Object.assign({}, contactConfig)
config.asnumber = {
  icon: 'info-as',
  color: 'rgb(1,90,125)',
  filter: /[^0-9]/g,
  regular: /^\d{1,7}$/,
  id: /^(.+)$/i,
  target: '_self',
  hrefPrefix: 'javascript:;'
}

config.opencorporates = {
  icon: 'info-opencorporates',
  color: 'rgb(159,31,52)',
  syncData: true,

  filter: /(https?:\/\/)?opencorporates.com\/companies\//,
  regular: /^https:\/\/opencorporates.com\/companies\/\S+/,
  id: /opencorporates\.com\/companies\/(\S+)\/?$/i,
  target: '_blank',
  hrefPrefix: '@url@'
}

config.dnb = {
  icon: 'info-dnb',
  color: 'rgb(0,81,114)',

  filter: /(https?:\/\/)?www.dnb.com\/business-directory\//,
  regular: /^https:\/\/www.dnb.com\/business-directory\/\S+/,
  id: /www\.dnb\.com\/business-directory\/company-profiles\.(.+?).html/i,
  target: '_blank',
  hrefPrefix: '@url@.html'
}

//https://mall.jd.com/index-605747.html
config.jd = {
  icon: 'info-jd',
  color: 'rgb(221,39,39)',

  filter: /(https?:\/\/)?mall.jd.com\//,
  regular: /^https:\/\/mall.jd.com\/index-\d+\.html/,
  id: /mall\.jd\.com\/index-(\d+)\.html/i,
  target: '_blank',
  hrefPrefix: '@url@'
}

//https://ywhaidi.1688.com/
//https://kingrole.en.alibaba.com/
config.alibaba = {
  icon: 'info-1688',
  color: 'rgb(255,115,0)',
  filter: /https?:\/\/|([\/?])[^/ ]*$/g,
  regular: /^https:\/\/[^.]+?\.(1688\.com|en\.alibaba\.com)[^\w]*$/i,
  id: /^https:\/\/([^.]+?)\.(1688\.com|en\.alibaba\.com)/i,
  target: '_blank',
  hrefPrefix: '@url@'
}

//https://kingston.tmall.com/
config.tmall = {
  icon: 'info-tmall',
  color: 'rgb(255,0,45)',
  filter: /https?:\/\/|(\/|\?)[^/ ]*$/,
  regular: /^https:\/\/[^.]+?\.tmall\.com[^\w]*$/i,
  id: /^https:\/\/([^.]+?)\.tmall\.com/i,
  target: '_blank',
  hrefPrefix: '@url@'
}

//https://www.ebay.com/usr/discountdesignerdeal
config.ebay = {
  icon: 'info-ebay',
  color: 'rgb(231, 46, 53)',

  filter: /(https?:\/\/)?([\w-]+\.)?ebay.com\/usr\/|[?/ ].+$/g,
  regular: /^https?:\/\/www.ebay.com\/usr\/[^?]{2,}/,
  id: /\/usr\/([^?/]+)/i,
  hrefPrefix: '@url@',
  target: '_blank'
}

//https://www.amazon.com/sp?seller=A2C9R5MCHNK940
// https://www.amazon.com/s?me=A3GO5VFCNOM5I7
// https://www.amazon.com/sp?seller=A3GO5VFCNOM5I7
config.amazon = {
  icon: 'info-amazon',
  color: 'rgb(58,85,141)',
  filter: /(https?:\/\/)?([\w-]+\.)?amazon.com\/((sp\?seller)|(s\?me))=/g,
  regular: /^https?:\/\/www.amazon.com\/sp\?seller=[^&?\s]{10,20}/,
  id: /\/sp\?seller=([^&?\s]{10,20})/i,
  hrefPrefix: '@url@',
  target: '_blank'
}

config.linkedin = {
  icon: 'info-linkedin',
  syncData: true,
  color: 'rgb(0,115,177)',

  filter: /(https?:\/\/)?([\w-]+\.)?linkedin.com\/(in|company)\//,
  regular: /^https?:\/\/([\w-]+).linkedin.com\/(in|company)\/\S{2,}/,
  id: /\/(?:in|company)\/([^\/]*?)(\/|\?|\S{0}$)/i, //\/?|\/.*?
  hrefPrefix: '@url@',
  target: '_blank'
}

config.crunchbase = {
  icon: 'info-cb',
  syncData: true,
  color: 'rgb(2, 136, 209)',
  filter: /(https?:\/\/)?([\w-]+\.)?crunchbase.com\/organization\//,
  regular: /^https?:\/\/www.crunchbase.com\/organization\/\S{2,}/,
  id: /\/organization\/([^\/]*?)(\/?|\/.*?)$/i,
  hrefPrefix: '@url@',
  target: '_blank'
}

config.tianyancha = {
  icon: 'info-tyc',
  syncData: true,
  color: 'rgb(0,132,255)',

  filter: /(https?:\/\/)?www.tianyancha.com\//,
  regular: /^https:\/\/www.tianyancha.com\/(?:company|brand|organize)\/\S+/,
  id: /www.tianyancha.com\/((?:company|brand|organize)\/\S+)/i,
  target: '_blank',
  hrefPrefix: '@url@'
}

config.qixin = {
  icon: 'info-qxb',
  syncData: true,
  color: 'rgb(253,208,0)',

  filter: /(https?:\/\/)?www.qixin.com\//,
  regular: /^https?:\/\/www.qixin.com\/(?:company|investor|brand)\/\S+/,
  id: /www.qixin.com\/((?:company|investor|brand)\/\S+)/i,
  hrefPrefix: '@url@',
  target: '_blank'
}

config.qcc = {
  icon: 'info-qcc',
  syncData: true,
  color: 'rgb(0,81,114)',

  filter: /(https?:\/\/)?www.qcc.com\//,
  regular: /^https:\/\/www.qcc.com\/(?:firm\/|groupdetail_|product\/)\S+\.html$/,
  id: /www.qcc.com\/((?:firm\/|groupdetail_|product\/)\S+)\.html/i,
  target: '_blank',
  hrefPrefix: '@url@'
}

config.zhihu = {
  icon: 'info-zhihu',
  color: 'rgb(14,136,235)',
  syncData: true,

  filter: /(https?:\/\/)?www\.zhihu.com\//g,
  regular: /^https?:\/\/www\.zhihu\.com\/(people|org)\/[\w-]{2,}/,
  id: /zhihu\.com\/((?:people|org)\/[\w-]{2,})/i,
  hrefPrefix: '@url@',
  target: '_blank'
}

config.itjuzi = {
  icon: 'info-itjuzi',
  syncData: true,
  color: 'rgb(255,137,102)',

  filter: /(https?:\/\/)?www\.itjuzi\.com\//g,
  regular: /^https?:\/\/www\.itjuzi\.com\/(company|investfirm)\/\d+/,
  id: /itjuzi\.com\/((?:company|investfirm)\/\d+)/i,
  hrefPrefix: '@url@',
  target: '_blank'
}

//https://paganresearch.io/details/clik-payment
config.paganresearch = {
  icon: 'info-pagan',
  syncData: false,
  color: 'rgb(14,136,235)',

  filter: /(https?:\/\/)?paganresearch\.io\/details\//g,
  regular: /^https?:\/\/paganresearch\.io\/details\/([\w-]{2,})/i,
  id: /\/details\/([\w-]{2,})/i,
  hrefPrefix: '@url@',
  target: '_blank'
}

config.craft = {
  icon: 'info-craft',
  color: 'rgb(127,84,170)',
  syncData: true,

  filter: /(https?:\/\/)?craft\.co\//g,
  regular: /^https?:\/\/craft\.co\/[\w-]+/,
  id: /craft\.co\/([\w-]+)/i,
  hrefPrefix: '@url@',
  target: '_blank'
}

//清科数据投资界
config.pedaily = {
  icon: 'info-tzj',
  syncData: true,
  color: 'rgb(18,150,219)',

  filter: /(https?:\/\/)?zdb\.pedaily\.cn\//g,
  regular: /^https?:\/\/zdb\.pedaily\.cn\/(enterprise|company)\/show\d+/,
  id: /pedaily\.cn\/((?:enterprise|company)\/show\d+)/i,
  hrefPrefix: '@url@',
  target: '_blank'
}

//创业帮
config.cyzone = {
  icon: 'info-cyb',
  syncData: true,
  color: 'rgb(253,116,0)',
  filter: /(https?:\/\/)?(data|www|bestla)\.cyzone\.cn\/(\/saas)?/g,
  regular: /^https?:\/\/(data|www|bestla)\.cyzone\.cn(\/saas)?\/(company|capital)\/[\w-]+/,
  id: /cyzone\.cn(?:\/saas)?\/((?:company|capital)\/[\w-]+)/i,
  hrefPrefix: '@url@',
  target: '_blank'
}

//创业帮
//https://www.wsj.com/market-data/quotes/345363534/company-people
//https://www.wsj.com/market-data/quotes/HK/1810/historical-prices
config.wsj = {
  icon: 'info-wsj',
  syncData: true,
  color: 'rgb(19,19,19)',
  filter: /(https?:\/\/)?(www.)?wsj\.com\/market-data\/quotes\//g,
  regular: /^https?:\/\/www\.wsj\.com\/market-data\/quotes\/[a-zA-Z]{2,}/,
  id: /wsj\.com\/market-data\/quotes\/([a-zA-Z0-9]{2,}(?:\/[\w-]+){0,2})(?:\/company-people)?/i,
  hrefPrefix: '@url@',
  target: '_blank'
}
config.medium = {
  icon: 'info-medium',
  syncData: true,
  color: 'rgb(19,19,19)',
  // filter:/(https?:\/\/)?medium\.com\/?/g,
  regular: /^https?:\/\/([\w-]+\.)?medium\.com\/?([\w-]+)?[\/about]?\??/g,
  id: /^https?:\/\/(?:[\w-]+\.)?medium\.com\/?([\w-]+)$/g,
  hrefPrefix: '@url@',
  target: '_blank'
}
//自有商城
config.shop = {
  icon: 'info-shop',
  syncData: false,
  color: 'rgb(255,80,0)',
  regular: /^https?:\/\/\S+\.\S+/,
  id: /^https:\/\/(.+)$/i,
  hrefPrefix: '@url@',
  target: '_blank'
}
////修改account linkedin前缀
//config.linkedin.prefix = { //前缀
//	content: 'linkedin.com/company/',
//	value: 'https://www.linkedin.com/company/',
//}
Object.freeze(config)
let ConfigArr: f2.info.Config[] = []
let menu: f2.info.Type[] = ['email', 'phone', 'linkedin', 'facebook', 'twitter', 'youtube', 'instagram', 'pinterest', 'wiki', 'qq', 'wechat', 'telegram', 'shop']
menu.forEach(key => {
  let info = config[key]
  if (info) {
    ConfigArr.push({
      type: key,
      ...info
    })
  }
})
Object.freeze(ConfigArr)
export {ConfigArr}
export default config
