export default class NameSplit {
  name: string = ''
  countryId: number = 0 //国家ID
  len: number = 0 //nameArr 长度

  /**
   * @param {string} name 名字
   * @param {number} countryId 国家ID，部分俄语国家可以根据名字区分性别
   * */
  getNames(name: string, countryId?: number) {
    if (name) this.name = ff.util.delSpecial(ff.util.trim(name).replace(/\s+/g, ' '))
    if (countryId) this.countryId = countryId
    let data: Crawler.ContactsName
    switch (this.lang) {
      case 'cn':
        data = this.splitZhName()
        break
      case 'ru':
        data = this.splitRuName()
        break
      default:
        data = this.splitName()
    }
    if (this.lang) data.lang = this.lang
    return data
  }

  get lang() {
    let lang: f2.Language = '',
      russian_ids = [172, 19, 110, 104, 215, 14, 63, 74, 112, 118, 135, 201, 212, 220, 10, 165, 170],
      zh_ids = [50, 87, 120, 203]
    if (ff.util.isChn(this.name, true)) lang = 'cn'
    else if (this.countryId) {
      if (russian_ids.includes(this.countryId)) lang = 'ru'
      else if (zh_ids.includes(this.countryId)) lang = 'cn'
    } else {
      if (ff.util.isEnn(this.name)) lang = 'en'
    }
    return lang
  }

  get namearr(): string[] {
    let arr = []
    if (this.lang === 'cn') {
      for (let i = 0; i < this.name.length; i++) {
        arr.push(this.name.charAt(i))
      }
    } else {
      arr = this.name.split(/\s+/).map(v => ff.util.trim(v))
    }
    arr = arr.filter(v => v)
    this.len = arr.length
    return arr
  }

  splitZhName() {
    let last_name = this.namearr[0],
      first_name = this.namearr.slice(1).join('')
    return {first_name, last_name}
  }

  splitRuName() {
    let last_name = this.namearr[0],
      first_name = this.namearr.slice(1).join(' '),
      gender = 1
    let v = this.namearr
    let va = v.filter(n => /va$/.test(n))
    if (!va.length) {
      //女
      va = v.filter(n => /v$/.test(n))
      gender = 0
    }
    if (va.length) {
      last_name = va[va.length - 1]
      first_name = v.filter(n => n !== last_name).join(' ')
    }
    return {first_name, last_name, gender}
  }

  splitName() {
    let last_name = this.namearr[this.len - 1],
      first_name = this.namearr.slice(0, this.len - 1).join(' ')
    return {first_name, last_name}
  }

  /**
   * 获取名字可选项
   * @param {string} name 当前input中的名字
   * @param {0 | 1} type  //0:first_name 1:last_name
   * */
  selectArr(name: string, type: 0 | 1) {
    let i = this.name.indexOf(name),
      opts = []

    if (i > -1) {
      let arr = this.namearr,
        l = arr[0]
      switch (type) {
        case 0:
          do {
            let f = arr.shift()
            if (!opts.length) {
              opts.push(l)
            } else {
              l = opts[opts.length - 1]
              if (this.lang === 'cn') opts.push([l, f].join(''))
              else opts.push([l, f].join(' '))
            }
          } while (arr.length > 1)
          break
        case 1:
          let lar = this.name.substr(i)
          let as = []
          if (ff.util.isChn(lar, true)) {
            for (let i = 0; i < lar.length; i++) {
              as.push(lar.charAt(i))
            }
          } else {
            as = lar.split(/\s+/).map(v => ff.util.trim(v))
          }
          do {
            if (as.length) {
              if (this.lang === 'cn') opts.push(as.join(''))
              else opts.push(as.join(' '))
            }
            as.shift()
          } while (as.length)
          break
      }
      return opts.filter(v => v)
    }
  }
}
