/// <reference path="../../types.d.ts" />
import gc from './src/gc';
import mqtt from './src/mqtt';
import { MezzFileType, MqttStatus, LiveActionType, Util } from '../common/util';
import Ajax from '../common/ajax';
import { CrawlerUtil } from './src/crawler/utils';
import CrawlerDb from './src/crawler/database';
import { AxiosRequestConfig, AxiosStatic, Canceler as C } from 'axios';
import AnalyzeText from './src/analyze-text';
import NameSplit from './src/name-split';
import error from '../common/error';
import DateTime from './src/date-time';
import ContactInfo from './src/contactInfo';
import Linkedin, { GetLiStatData, LinkedinAccount } from './src/linkedin';
import CountryClass, { Country as Co, CountryBase as CB } from './src/country';
import env from '../common/env';
import * as Gc from "../gc.type";
/**
 * @desc 渲染进程全局变量
 * @author 黄敏
 * @创建时间 2022-08-02 15:15
 **/
declare type ValueOf<T> = T[keyof T];
declare global {
    namespace Axios {
        type Canceler = C;
        type RequestConfig = AxiosRequestConfig;
    }
    namespace ff {
        type MezzFileType = ValueOf<typeof MezzFileType>;
        type MqttStatus = ValueOf<typeof MqttStatus>;
        type LiveActionType = ValueOf<typeof LiveActionType>;
        namespace mqtt {
            interface Subs {
                [topic: string]: (...data: any) => void;
            }
        }
        namespace gc {
            type KeyboardShortcut = Gc.KeyboardShortcut;
            type Client = Gc.Client;
            type IpcTopic = Gc.IpcTopic;
            type Subscribes = Gc.Subscribes;
        }
        namespace country {
            type CountryBase = CB;
            type Country = Co;
        }
        namespace linkedin {
            type AccountStatus = LinkedinAccount;
            type LiStatData = GetLiStatData;
        }
    }
}
declare global {
    var ff: Readonly<{
        env: typeof env;
        MezzFileType: typeof MezzFileType;
        MqttStatus: typeof MqttStatus;
        LiveActionType: typeof LiveActionType;
        Ajax: typeof Ajax;
        util: Util;
        error: typeof error;
        gc: typeof gc;
        mqtt: typeof mqtt;
        axios: AxiosStatic;
        nameSplit: NameSplit;
        dateTime: typeof DateTime;
        contactInfo: typeof ContactInfo;
        linkedin: Linkedin;
        country: CountryClass;
        analyzeText: {
            company: AnalyzeText;
            contact: AnalyzeText;
        };
        crawler: {
            util: CrawlerUtil;
            db: CrawlerDb;
        };
    }>;
}
export {};
