import * as config from './linkedin/lisn.config';
/**
 * @用途 通讯类，linkedin、facebook等通讯
 * @author 黄敏
 * @创建时间 2022-08-11 10:26
 **/
interface SendMessaging {
    code: number;
    isFriend: boolean;
    isPending?: boolean;
}
interface CancelCb {
    (cancel: Axios.Canceler): void;
}
export declare enum LinkedinAccount {
    nologin = 1,
    default = 2,
    sales = 3
}
interface liErr {
    code: number;
    msg: string;
    time: number;
    type: string;
    conn_m: number;
}
interface Stat {
    li_id: string | number;
    li_uid?: string;
    type: string;
    code?: number;
    msg?: string | object;
}
interface Friend {
    id: number;
    friend_status?: 0 | 1 | 2;
}
export declare type GetLiStatData = {
    failure: {
        id: number;
        type: string;
        user_id: number;
        li_id: string;
        create_time: number;
        code: number;
        msg: string;
        friend_status: number;
        project_id: number;
        li_uid: string;
    }[];
} & {
    [key: string]: {
        [key: string]: number;
    };
};
declare class Linkedin {
    readonly config: Readonly<typeof config>;
    readonly nologin = 1;
    readonly default = 2;
    readonly sales = 3;
    login_status: number;
    login_number_id: number;
    getDBContact(UID: string): Promise<Crawler.Contact | null>;
    /**
     * 获取linkedin的好友申请数量
     * */
    getInvitationCount(): Promise<any>;
    /**
     * 获取linkedin的好友申请列表
     * */
    getInvitationList(page?: number, size?: number): Promise<any>;
    getContactBase(UID: string): Promise<Crawler.Contact | null>;
    /**
     * linkedin 好友邀请/发送消息上报
     * */
    setStat(data: Stat | Friend): Promise<any>;
    /**
     * linkedin 获取统计
     * */
    getStat(li_id: string | number): Promise<GetLiStatData>;
    /**
     * @Description: 根据liID获取aaxa队列信息
     * @author bear
     * @date 2021/8/12
     **/
    getDetail(li_uid: string): Promise<any>;
    get liErr(): {
        get(): any;
        set(liErr: liErr): void;
        remove(): void;
    };
    /**
     * 'https://www.linkedin.com/pub/vlad-cealicu/2/807/29a'
     * linkedin 老格式转换，/pub/vlad-cealicu/2/807/29a
     * */
    pubToIn(url: string): Promise<string>;
    /**
     * 提取图片信息
     * @param {{artifacts: any[]; rootUrl: string}} picture linkedin通用格式
     * */
    extractImageUrl(picture: {
        artifacts: any[];
        rootUrl: string;
    }): string;
    /**
     * 从linkedin的targetUrn中提取UniqueId
     * targetUrn格式：urn:li:fs_miniProfile:ACoAAAqEjnEBNiMcjmpeCpYs09szr2LFNeFN8dk
     * @param targetUrn
     * @param type
     * @return {String}
     * */
    getLinkedinUniqueId(targetUrn: string, type?: Crawler.DataType): string;
    getToken(): Promise<string>;
    /**
     * 获取当前登录者 数字ID
     * https://www.linkedin.com/psettings/policy/notices?types=COMMENTS_VISIBILITY
     * */
    getNumberId(): Promise<number>;
    /**
     * 获取linkedin的密文id
     * @param {string} uid uid是连接中 https://www.linkedin.com/in/yourk-soboros-181b0a63 中的 yourk-soboros-181b0a63
     * */
    getUrnId(uid: string): Promise<string>;
    ajaxErrorHandle(e: any): void;
    ajax(url: string, data?: {
        [key: string]: any;
    }, type?: 'get' | 'post', cancelCb?: CancelCb, headers?: {
        [key: string]: string | number;
    }): Promise<any>;
    getEndId(urn: string | undefined): string;
    getFriendInfo(uid: string, noCache?: boolean): Promise<Crawler.FriendInfo>;
    /**
     * 撤回好友邀请
     * https://www.linkedin.com/voyager/api/relationships/invitations?action=closeInvitations
     * linkedin接口是单个的，这里传多个也能成功。
     * */
    cancelInviate(id: any, stat?: {
        msg: string | object;
        li_uid: string;
        type: string;
    }[]): Promise<void>;
    /**
     * 用手机发送好友邀请
     * @li ID
     * @aaxa 任务ID
     */
    sentInvite(uid: string, ext: {
        task_id: number;
        contact_id: number;
        info_id: number;
    }): Promise<void>;
    setLimit(data: {
        li_uid?: string;
        code?: number;
        type: 'connect' | 'connect_m' | string;
        msg: string | object;
    }): Promise<void>;
    sendConnect(uid: string, profileId: string, content: string): Promise<Crawler.FriendInfo>;
    private _noMidMessageing;
    sendMessaging(uid: string, centent: string, contactOrigins?: Crawler.FriendInfo | null): Promise<SendMessaging>;
    getConnections(url?: string): Promise<Crawler.Result>;
}
export default Linkedin;
